save_csv()
Save a list of row dicts to a CSV file.
Usage
save_csv(
data,
path,
*,
delimiter=",",
)Parameters
data: list[dict]-
Rows to write.
path: str-
Destination file path.
delimiter: str = ","-
Column separator character.
Save a list of row dicts to a CSV file.
Usage
data: list[dict]Rows to write.
path: strDestination file path.
delimiter: str = ","Column separator character.